import type { RNINavigatorRouteViewProps } from '../native_components/RNINavigatorRouteView';
import type { EdgeInsets, Rect } from '../types/MiscTypes';
export declare type NativePushPopOptions = {
    isAnimated?: boolean;
};
export declare type NativeRouteData = {
    type: 'viewController';
} | ({
    type: 'reactRoute' | 'nativeRoute';
} & Pick<RNINavigatorRouteViewProps, 'routeID' | 'routeKey' | 'routeIndex'>);
export declare type NavigatorConstantsObject = {
    navigatorID: number;
    navBarHeight: number;
    statusBarHeight: number;
    safeAreaInsets: EdgeInsets;
    bounds: Rect;
    isPresenting: boolean;
    activeRoutes: Array<NativeRouteData>;
    topViewController?: NativeRouteData;
    visibleViewController?: NativeRouteData;
};
interface RNINavigatorViewModule {
    push(node: number, routeID: number, options: Readonly<NativePushPopOptions>): Promise<void>;
    pop(node: number, options: Readonly<NativePushPopOptions>): Promise<{
        routeKey: string;
        routeIndex: number;
    }>;
    setNavigationBarHidden(node: number, isHidden: boolean, animated: boolean): Promise<void>;
    popToRoot(node: number, options: Readonly<NativePushPopOptions>): Promise<void>;
    removeRoute(node: number, routeID: number, routeIndex: number, animated: boolean): Promise<void>;
    removeRoutes(node: number, itemsToRemove: readonly Readonly<{
        routeID: number;
        routeIndex: number;
    }>[], animated: boolean): Promise<void>;
    replaceRoute(node: number, prevRouteIndex: number, prevRouteID: number, nextRouteID: number, animated: boolean): Promise<void>;
    insertRoute(node: number, nextRouteID: number, atIndex: number, animated: boolean): Promise<void>;
    setRoutes(node: number, nextRouteIDs: readonly number[], animated: boolean): Promise<void>;
    getNativeRouteKeys(callback: (keys: [string]) => void): void;
    sendCustomCommandToNative(node: number, commandKey: string, commandData: Readonly<object> | null): Promise<object | null>;
    getNavigatorConstants(node: number): Promise<NavigatorConstantsObject>;
}
export declare const RNINavigatorViewModule: RNINavigatorViewModule;
export {};
